@@ -1,7 +1,7 @@
 package Mojo::HelloMojo;
 use Mojolicious::Lite;
 
-our $VERSION  = '0.03';
+our $VERSION  = '0.04';
 
 use Cwd;
 
@@ -18,11 +18,15 @@ foreach my $app_dir ( $ENV{HELLO_MOJO} ? split /:/, $ENV{HELLO_MOJO} : @{app->co
       app->log->info("No Mojo for $app, skipping");
     } elsif ( $app && -f $app ) {
       my $mount = plugin Mount => {"/$_" => $app};
-      app->log->info("Mounted /$_ => $app");
+      my $home = $mount->pattern->defaults->{app}->home;
+      my ($rel_app) = ($app =~ /^$home\W(.*)$/);
+      app->log->info("Mounted /$_ => $home / $rel_app");
       if ( my $domain = $mount->pattern->defaults->{app}->config('domain') ) {
         foreach my $d ( ref $domain eq 'ARRAY' ? @$domain : $domain ) {
           my $mount = plugin Mount => {$d => $app};
-          app->log->info("Mounted $d => $app");
+          my $home = $mount->pattern->defaults->{app}->home;
+          my ($rel_app) = ($app =~ /^$home\W(.*)$/);
+          app->log->info("Mounted $d => $home / $rel_app");
         }
       }
     } else {
